aboutsummaryrefslogtreecommitdiffstats
path: root/shared
diff options
context:
space:
mode:
authorTeemu Suo-Anttila <tsuoanttila@users.noreply.github.com>2017-06-15 15:44:56 +0300
committerIlia Motornyi <elmot@vaadin.com>2017-06-15 15:44:56 +0300
commitf76cc830efa7f4823e8eed272de8b5ca2cfebfc3 (patch)
treeab13cc3048b193e24516eaff8c3d7d5755f78334 /shared
parentca437c758b0bffb7760d93d64021fbb2917a35fd (diff)
downloadvaadin-framework-f76cc830efa7f4823e8eed272de8b5ca2cfebfc3.tar.gz
vaadin-framework-f76cc830efa7f4823e8eed272de8b5ca2cfebfc3.zip
Rewrite HierarchyMapper to consistently handle changes
Fixes #9449 Fixes #9490 Fixes #9448 Fixes #9465
Diffstat (limited to 'shared')
-rw-r--r--shared/src/main/java/com/vaadin/shared/ui/treegrid/FocusParentRpc.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/shared/src/main/java/com/vaadin/shared/ui/treegrid/FocusParentRpc.java b/shared/src/main/java/com/vaadin/shared/ui/treegrid/FocusParentRpc.java
index 856b3369db..333fc84d35 100644
--- a/shared/src/main/java/com/vaadin/shared/ui/treegrid/FocusParentRpc.java
+++ b/shared/src/main/java/com/vaadin/shared/ui/treegrid/FocusParentRpc.java
@@ -28,10 +28,10 @@ public interface FocusParentRpc extends ServerRpc {
/**
* Focuses cell in the row parent
*
* @param rowIndex
* the row index
* @param cellIndex
* the cell index
*/
- void focusParent(int rowIndex, int cellIndex);
+ void focusParent(String rowKey, int cellIndex);
}
@@ -28,10 +28,10 @@ public interface FocusParentRpc extends ServerRpc {
* Focuses cell in the row parent
*
- * @param rowIndex
- * the row index
+ * @param rowKey
+ * the row key
* @param cellIndex
* the cell index